pub async fn finalize_block<B, F, CB>(params: FinalizeBlockParams<B, F, CB>)Expand description
finalizes a block in the backend with the given params.
pub async fn finalize_block<B, F, CB>(params: FinalizeBlockParams<B, F, CB>)finalizes a block in the backend with the given params.